==> scotch_6.0.4.dfsg1.orig.tar.gz: scotch-6.0.4.dfsg/src/libscotch/hmesh_order_hx.h <==
/* Copyright 2004,2007 ENSEIRB, INRIA & CNRS
**
** This file is part of the Scotch software package for static mapping,
** graph partitioning and sparse matrix ordering.
**
** This software is governed by the CeCILL-C license under French law
** and abiding by the rules of distribution of free software. You can
** use, modify and/or redistribute the software under the terms of the
** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
** URL: "http://www.cecill.info".
** 
** As a counterpart to the access to the source code and rights to copy,
** modify and redistribute granted by the license, users are provided
** only with a limited warranty and the software's author, the holder of
** the economic rights, and the successive licensors have only limited
** liability.
** 
** In this respect, the user's attention is drawn to the risks associated
** with loading, using, modifying and/or developing or reproducing the
** software by the user in light of its specific status of free software,
** that may mean that it is complicated to manipulate, and that also
** therefore means that it is reserved for developers and experienced
** professionals having in-depth computer knowledge. Users are therefore
** encouraged to load and test the software's suitability as regards
** their requirements in conditions enabling the security of their
** systems and/or data to be ensured and, more generally, to use and
** operate it in the same conditions as regards security.
** 
** The fact that you are presently reading this means that you have had
** knowledge of the CeCILL-C license and that you accept its terms.
*/
/************************************************************/
/**                                                        **/
/**   NAME       : hmesh_order_hx.h                        **/
/**                                                        **/
/**   AUTHOR     : Francois PELLEGRINI                     **/
/**                                                        **/
/**   FUNCTION   : This module contains the data declara-  **/
/**                tions for the halo mesh block Approxi-  **/
/**                mate (Multiple) Minimum Degree and Fill **/
/**                ordering routines.                      **/
/**                                                        **/
/**   DATES      : # Version 4.0  : from : 09 dec 2003     **/
/**                                 to     09 dec 2003     **/
/**                                                        **/
/************************************************************/

/*
**  The defines.
*/

#define HMESHORDERHXHASHPRIME       17            /* Prime number */

/*
**  The type and structure definitions.
*/

/*+ A table made of such elements is used to compute
    the external degree of non-halo vertices.        +*/

typedef struct HmeshOrderHxHash_ {
  Gnum                      vertnum;              /*+ Origin vertex (i.e. pass) number +*/
  Gnum                      vertend;              /*+ End vertex number in mesh        +*/
} HmeshOrderHxHash;

/*
**  The function prototypes.
*/

#ifndef HMESH_ORDER_HX
#define static
#endif

int                         hmeshOrderHxFill    (const Hmesh * restrict const, Gnum * restrict const, Gnum * restrict const, Gnum * restrict const, Gnum * restrict const, Gnum * restrict const);

#undef static

==> scotch_6.0.9.orig.tar.gz: scotch_6.0.9/src/libscotch/hmesh_order_hx.h <==
/* Copyright 2004,2007,2018 IPB, Universite de Bordeaux, INRIA & CNRS
**
** This file is part of the Scotch software package for static mapping,
** graph partitioning and sparse matrix ordering.
**
** This software is governed by the CeCILL-C license under French law
** and abiding by the rules of distribution of free software. You can
** use, modify and/or redistribute the software under the terms of the
** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
** URL: "http://www.cecill.info".
** 
** As a counterpart to the access to the source code and rights to copy,
** modify and redistribute granted by the license, users are provided
** only with a limited warranty and the software's author, the holder of
** the economic rights, and the successive licensors have only limited
** liability.
** 
** In this respect, the user's attention is drawn to the risks associated
** with loading, using, modifying and/or developing or reproducing the
** software by the user in light of its specific status of free software,
** that may mean that it is complicated to manipulate, and that also
** therefore means that it is reserved for developers and experienced
** professionals having in-depth computer knowledge. Users are therefore
** encouraged to load and test the software's suitability as regards
** their requirements in conditions enabling the security of their
** systems and/or data to be ensured and, more generally, to use and
** operate it in the same conditions as regards security.
** 
** The fact that you are presently reading this means that you have had
** knowledge of the CeCILL-C license and that you accept its terms.
*/
/************************************************************/
/**                                                        **/
/**   NAME       : hmesh_order_hx.h                        **/
/**                                                        **/
/**   AUTHOR     : Francois PELLEGRINI                     **/
/**                                                        **/
/**   FUNCTION   : This module contains the data declara-  **/
/**                tions for the halo mesh block Approxi-  **/
/**                mate (Multiple) Minimum Degree and Fill **/
/**                ordering routines.                      **/
/**                                                        **/
/**   DATES      : # Version 4.0  : from : 09 dec 2003     **/
/**                                 to     09 dec 2003     **/
/**                # Version 6.0  : from : 30 apr 2018     **/
/**                                 to   : 07 jun 2018     **/
/**                                                        **/
/************************************************************/

/*
**  The defines.
*/

#define HMESHORDERHXHASHPRIME       17            /* Prime number */

/*
**  The type and structure definitions.
*/

/*+ A table made of such elements is used to compute
    the external degree of non-halo vertices.        +*/

typedef struct HmeshOrderHxHash_ {
  Gnum                      vertnum;              /*+ Origin vertex (i.e. pass) number +*/
  Gnum                      vertend;              /*+ End vertex number in mesh        +*/
} HmeshOrderHxHash;

/*
**  The function prototypes.
*/

int                         hmeshOrderHxFill    (const Hmesh * restrict const, Gnum * restrict const, Gnum * restrict const, Gnum * restrict const, Gnum * restrict const, Gnum * restrict const, Gnum * restrict const);
